# -*- coding: utf-8 -*-
from yookassa.domain.common import PaymentMethodType
from yookassa.domain.common.response_object import ResponseObject
from yookassa.domain.models import CancellationDetails
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.deal import RefundDealInfo
from yookassa.domain.models.refund_data.refund_data_class_map import RefundDataClassMap
from yookassa.domain.models.refund_data.refund_data_factory import RefundDataFactory
from yookassa.domain.models.refund_data.refund_source import RefundSource


class RefundResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе информации о возврате.
    """  # noqa: E501

    __id = None
    """Идентификатор возврата платежа в ЮKassa."""  # noqa: E501

    __payment_id = None
    """Идентификатор платежа в ЮKassa."""  # noqa: E501

    __status = None
    """Статус возврата."""  # noqa: E501

    __cancellation_details = None
    """Комментарий к статусу `canceled`."""  # noqa: E501

    __receipt_registration = None
    """Статус регистрации чека."""  # noqa: E501

    __created_at = None
    """Время создания возврата. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601), например ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __amount = None
    """Сумма возврата."""  # noqa: E501

    __description = None
    """Комментарий, основание для возврата средств покупателю."""  # noqa: E501

    __sources = None
    """Данные о том, с какого магазина и какую сумму нужно удержать для проведения возврата. Присутствует, если вы используете %[Сплитование платежей](/developers/solutions-for-platforms/split-payments/basics)."""  # noqa: E501

    __deal = None
    """Данные о сделке, в составе которой проходит возврат."""  # noqa: E501

    __refund_method = None
    """Детали возврата. Зависят от способа оплаты, который использовался при проведении платежа."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели RefundResponse.

        :return: id модели RefundResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели RefundResponse.

        :param value: id модели RefundResponse.
        :type value: str
        """
        self.__id = value

    @property
    def payment_id(self):
        """
        Возвращает payment_id модели RefundResponse.

        :return: payment_id модели RefundResponse.
        :rtype: str
        """
        return self.__payment_id

    @payment_id.setter
    def payment_id(self, value):
        """
        Устанавливает payment_id модели RefundResponse.

        :param value: payment_id модели RefundResponse.
        :type value: str
        """
        self.__payment_id = value

    @property
    def status(self):
        """
        Возвращает status модели RefundResponse.

        :return: status модели RefundResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели RefundResponse.

        :param value: status модели RefundResponse.
        :type value: str
        """
        self.__status = value

    @property
    def cancellation_details(self):
        """
        Возвращает cancellation_details модели RefundResponse.

        :return: cancellation_details модели RefundResponse.
        :rtype: CancellationDetails
        """
        return self.__cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, value):
        """
        Устанавливает cancellation_details модели RefundResponse.

        :param value: cancellation_details модели RefundResponse.
        :type value: CancellationDetails
        """
        self.__cancellation_details = CancellationDetails(value)

    @property
    def receipt_registration(self):
        """
        Возвращает receipt_registration модели RefundResponse.

        :return: receipt_registration модели RefundResponse.
        :rtype: str
        """
        return self.__receipt_registration

    @receipt_registration.setter
    def receipt_registration(self, value):
        """
        Устанавливает receipt_registration модели RefundResponse.

        :param value: receipt_registration модели RefundResponse.
        :type value: str
        """
        self.__receipt_registration = value

    @property
    def created_at(self):
        """
        Возвращает created_at модели RefundResponse.

        :return: created_at модели RefundResponse.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """
        Устанавливает created_at модели RefundResponse.

        :param value: created_at модели RefundResponse.
        :type value: datetime
        """
        self.__created_at = value

    @property
    def amount(self):
        """
        Возвращает amount модели RefundResponse.

        :return: amount модели RefundResponse.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели RefundResponse.

        :param value: amount модели RefundResponse.
        :type value: Amount
        """
        self.__amount = Amount(value)

    @property
    def description(self):
        """
        Возвращает description модели RefundResponse.

        :return: description модели RefundResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели RefundResponse.

        :param value: description модели RefundResponse.
        :type value: str
        """
        self.__description = value

    @property
    def sources(self):
        """
        Возвращает sources модели RefundResponse.

        :return: sources модели RefundResponse.
        :rtype: list[RefundSource]
        """
        return self.__sources

    @sources.setter
    def sources(self, value):
        """
        Устанавливает sources модели RefundResponse.

        :param value: sources модели RefundResponse.
        :type value: list[RefundSource]
        """
        if isinstance(value, list):
            self.__sources = [RefundSource(item) for item in value]
        else:
            self.__sources = value

    @property
    def deal(self):
        """
        Возвращает deal модели RefundResponse.

        :return: deal модели RefundResponse.
        :rtype: RefundDealInfo
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели RefundResponse.

        :param value: deal модели RefundResponse.
        :type value: RefundDealInfo
        """
        self.__deal = RefundDealInfo(value)

    @property
    def refund_method(self):
        """
        Возвращает refund_method модели RefundResponse.

        :return: refund_method модели RefundResponse.
        :rtype: ResponseRefundData
        """
        return self.__refund_method

    @refund_method.setter
    def refund_method(self, value):
        """
        Устанавливает refund_method модели RefundResponse.

        :param value: refund_method модели RefundResponse.
        :type value: ResponseRefundData
        """
        if isinstance(value, dict) and 'type' in value and value['type'] not in RefundDataClassMap().response:
            value['type'] = PaymentMethodType.UNKNOWN
        self.__refund_method = RefundDataFactory().create(value, self.context())



# -*- coding: utf-8 -*-
from yookassa.domain.request.receipt_request import ReceiptRequest


class ReceiptRequestBuilder(object):
    """
    Конструктор запроса на создание чека.
    """  # noqa: E501
    
    def __init__(self):
        self.__request = ReceiptRequest()

    def set_type(self, value):
        """
        Устанавливает type модели ReceiptRequestBuilder.

        :param value: type модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.type = value
        return self

    def set_payment_id(self, value):
        """
        Устанавливает type модели ReceiptRequestBuilder.

        :param value: type модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.payment_id = value
        return self

    def set_refund_id(self, value):
        """
        Устанавливает refund_id модели ReceiptRequestBuilder.

        :param value: refund_id модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.refund_id = value
        return self

    def set_send(self, value):
        """
        Устанавливает send модели ReceiptRequestBuilder.

        :param value: send модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.send = value
        return self

    def set_customer(self, value):
        """
        Устанавливает customer модели ReceiptRequestBuilder.

        :param value: customer модели ReceiptRequestBuilder.
        :type value: ReceiptCustomer
        :rtype: ReceiptRequestBuilder
        """
        self.__request.customer = value
        return self

    def set_phone(self, value):
        """
        Устанавливает phone модели ReceiptRequestBuilder.

        :param value: phone модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.phone = value
        return self

    def set_email(self, value):
        """
        Устанавливает email модели ReceiptRequestBuilder.

        :param value: email модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.email = value
        return self

    def set_tax_system_code(self, value):
        """
        Устанавливает tax_system_code модели ReceiptRequestBuilder.

        :param value: tax_system_code модели ReceiptRequestBuilder.
        :type value: int
        :rtype: ReceiptRequestBuilder
        """
        self.__request.tax_system_code = value
        return self

    def set_items(self, value):
        """
        Устанавливает items модели ReceiptRequestBuilder.

        :param value: items модели ReceiptRequestBuilder.
        :type value: list[ReceiptItemRequest]
        :rtype: ReceiptRequestBuilder
        """
        self.__request.items = value
        return self

    def set_settlements(self, value):
        """
        Устанавливает settlements модели ReceiptRequestBuilder.

        :param value: settlements модели ReceiptRequestBuilder.
        :type value: list[Settlement]
        :rtype: ReceiptRequestBuilder
        """
        self.__request.settlements = value
        return self

    def set_on_behalf_of(self, value):
        """
        Устанавливает on_behalf_of модели ReceiptRequestBuilder.

        :param value: on_behalf_of модели ReceiptRequestBuilder.
        :type value: str
        :rtype: ReceiptRequestBuilder
        """
        self.__request.on_behalf_of = value
        return self

    def set_receipt_operational_details(self, value):
        """
        Устанавливает receipt_operational_details модели ReceiptRequestBuilder.

        :param value: receipt_operational_details модели ReceiptRequestBuilder.
        :type value: OperationalDetails
        :rtype: ReceiptRequestBuilder
        """
        self.__request.receipt_operational_details = value
        return self

    def set_receipt_industry_details(self, value):
        """
        Устанавливает receipt_industry_details модели ReceiptRequestBuilder.

        :param value: receipt_industry_details модели ReceiptRequestBuilder.
        :type value: list[IndustryDetails]
        :rtype: ReceiptRequestBuilder
        """
        self.__request.receipt_industry_details = value
        return self

    def set_additional_user_props(self, value):
        """
        Устанавливает additional_user_props модели ReceiptRequestBuilder.

        :param value: additional_user_props модели ReceiptRequestBuilder.
        :type value: AdditionalUserProps
        :rtype: ReceiptRequestBuilder
        """
        self.__request.additional_user_props = value
        return self

    def build(self):
        """
        Возвращает request модели ReceiptRequestBuilder.

        :return: request модели ReceiptRequestBuilder.
        :rtype: ReceiptRequest
        """
        return self.__request



# coding: utf-8
from yookassa.domain.common import BaseObject


class SbpParticipantBank(BaseObject):
    """
    Участник СБП (Системы быстрых платежей ЦБ РФ)
    """  # noqa: E501

    __bank_id = None
    """Идентификатор банка или платежного сервиса в СБП."""  # noqa: E501

    __name = None
    """Название банка или платежного сервиса в СБП."""  # noqa: E501

    __bic = None
    """Банковский идентификационный код (БИК) банка или платежного сервиса."""  # noqa: E501

    @property
    def bank_id(self):
        """
        Возвращает bank_id модели SbpParticipantBank.

        :return: bank_id модели SbpParticipantBank.
        :rtype: str
        """
        return self.__bank_id

    @bank_id.setter
    def bank_id(self, value):
        """
        Устанавливает bank_id модели SbpParticipantBank.

        :param value: bank_id модели SbpParticipantBank.
        :type value: str
        """
        self.__bank_id = str(value)

    @property
    def name(self):
        """
        Возвращает name модели SbpParticipantBank.

        :return: name модели SbpParticipantBank.
        :rtype: str
        """
        return self.__name

    @name.setter
    def name(self, value):
        """
        Устанавливает name модели SbpParticipantBank.

        :param value: name модели SbpParticipantBank.
        :type value: str
        """
        self.__name = str(value)

    @property
    def bic(self):
        """
        Возвращает bic модели SbpParticipantBank.

        :return: bic модели SbpParticipantBank.
        :rtype: str
        """
        return self.__bic

    @bic.setter
    def bic(self, value):
        """
        Устанавливает bic модели SbpParticipantBank.

        :param value: bic модели SbpParticipantBank.
        :type value: str
        """
        self.__bic = str(value)



# -*- coding: utf-8 -*-
import logging

from yookassa.domain.common.user_agent import Version
from yookassa.logging.adapter import Adapter


class ConfigurationError(Exception):
    """
    Ошибка конфигурации запроса. Не установлены параметры авторизации.
    """  # noqa: E501
    pass


class Configuration(object):
    """
    Класс для загрузки конфига API клиента.
    """  # noqa: E501

    api_url = "https://api.yookassa.ru/v3"
    """Базовый URL для API Кассы."""
    account_id = None
    """Идентификатор магазина"""
    secret_key = None
    """Секретный ключ."""
    timeout = 1800
    """Время через которое будут осуществляться повторные запросы."""
    max_attempts = 3
    """Количество повторных запросов при ответе API статусом 202."""
    auth_token = None
    """OAuth токен."""
    logger = None
    """Объект для логирования запросов."""
    agent_framework = None
    """Версия фреймворка."""
    agent_cms = None
    """Версия CMS."""
    agent_module = None
    """Версия модуля."""
    verify = None
    """Проверка сертификата (bool)."""

    def __init__(self, **kwargs):
        self.assert_has_api_credentials()

    @staticmethod
    def configure(account_id, secret_key, logger=None, **kwargs):
        """
        Устанавливает настройки конфигурации для базовой авторизации.

        :param account_id: Идентификатор магазина.
        :param secret_key: Секретный ключ.
        :param logger: Объект для логирования запросов.
        :param kwargs: Словарь с дополнительными параметрами.
        """
        Configuration.account_id = account_id
        Configuration.secret_key = secret_key
        Configuration.auth_token = None
        Configuration.configure_logger(logger)
        Configuration.api_url = kwargs.get("api_url", "https://api.yookassa.ru/v3")
        Configuration.timeout = kwargs.get("timeout", 1800)
        Configuration.max_attempts = kwargs.get("max_attempts", 3)
        Configuration.verify = kwargs.get("verify", None)

    @staticmethod
    def configure_auth_token(token, logger=None, **kwargs):
        """
        Устанавливает настройки конфигурации для авторизации по OAuth.

        :param token: OAuth токен.
        :param logger: Объект для логирования запросов.
        :param kwargs: Словарь с дополнительными параметрами.
        """
        Configuration.account_id = None
        Configuration.secret_key = None
        Configuration.auth_token = token
        Configuration.configure_logger(logger)
        Configuration.api_url = kwargs.get("api_url", "https://api.yookassa.ru/v3")
        Configuration.timeout = kwargs.get("timeout", 1800)
        Configuration.max_attempts = kwargs.get("max_attempts", 3)
        Configuration.verify = kwargs.get("verify", None)

    @staticmethod
    def configure_logger(logger):
        """
        Устанавливает настройки конфигурации для логирования.

        :param logger: Объект для логирования запросов.
        """
        if isinstance(logger, logging.Logger):
            Configuration.logger = Adapter(logger, {"context": {}})

    @staticmethod
    def configure_user_agent(framework=None, cms=None, module=None):
        """
        Устанавливает настройки конфигурации для User-Agent.

        :param framework: Версия фреймворка.
        :param cms: Версия CMS.
        :param module: Версия модуля.
        """
        if isinstance(framework, Version):
            Configuration.agent_framework = framework
        if isinstance(cms, Version):
            Configuration.agent_cms = cms
        if isinstance(module, Version):
            Configuration.agent_module = module

    @staticmethod
    def instantiate():
        """
        Получение объекта конфигурации.

        :return: Configuration
        """
        return Configuration(
            shop_id=Configuration.account_id,
            shop_password=Configuration.secret_key,
            timeout=Configuration.timeout,
            max_attempts=Configuration.max_attempts,
            auth_token=Configuration.auth_token,
            agent_framework=Configuration.agent_framework,
            agent_cms=Configuration.agent_cms,
            agent_module=Configuration.agent_module,
            logger=Configuration.logger,
            api_url=Configuration.api_url,
            verify=Configuration.verify
        )

    @staticmethod
    def api_endpoint():
        """
        Получение объекта конфигурации базового URL для API Кассы.

        :return: str
        """
        return Configuration.api_url

    def has_api_credentials(self):
        """
        Установлены ли параметры для базовой авторизации.

        :return: bool
        """
        return self.account_id is not None and self.secret_key is not None

    def assert_has_api_credentials(self):
        """
        Установлены ли параметры для базовой авторизации или авторизации по OAuth.
        Если параметры не установлены, то будет вызвано исключение ConfigurationError
        """
        if self.auth_token is None and not self.has_api_credentials():
            raise ConfigurationError("account_id and secret_key are required")
        elif self.auth_token and self.has_api_credentials():
            raise ConfigurationError("Could not configure authorization with auth_token and basic auth")



# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class InternalServerError(ApiError):
    """
    Ошибка авторизации. Не установлен заголовок.
    """  # noqa: E501
    HTTP_CODE = 500



# -*- coding: utf-8 -*-
"""Top-level package for YooKassa API Python Client Library."""

from yookassa.domain.notification.webhook_notification import *
from yookassa.domain.notification.webhook_notification_types import *



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.payment_data.payment_data import PaymentData


class PaymentDataB2bSberbank(PaymentData):
    """
    Данные для оплаты через СберБанк Бизнес Онлайн.
    """  # noqa: E501

    __payment_purpose = None
    """Назначение платежа (не больше 210 символов)."""  # noqa: E501

    __vat_data = None
    """Данные об НДС."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataB2bSberbank, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.B2B_SBERBANK:
            self.type = PaymentMethodType.B2B_SBERBANK

    @property
    def payment_purpose(self):
        """
        Возвращает payment_purpose модели PaymentDataB2bSberbank.

        :return: payment_purpose модели PaymentDataB2bSberbank.
        :rtype: str
        """
        return self.__payment_purpose

    @payment_purpose.setter
    def payment_purpose(self, value):
        """
        Устанавливает payment_purpose модели PaymentDataB2bSberbank.

        :param value: payment_purpose модели PaymentDataB2bSberbank.
        :type value: str
        """
        self.__payment_purpose = str(value)

    @property
    def vat_data(self):
        """
        Возвращает vat_data модели PaymentDataB2bSberbank.

        :return: vat_data модели PaymentDataB2bSberbank.
        :rtype: VatData
        """
        return self.__vat_data

    @vat_data.setter
    def vat_data(self, value):
        """
        Устанавливает vat_data модели PaymentDataB2bSberbank.

        :param value: vat_data модели PaymentDataB2bSberbank.
        :type value: VatData
        """
        if isinstance(value, dict):
            self.__vat_data = VatData(value)
        elif isinstance(value, VatData):
            self.__vat_data = value
        else:
            raise TypeError('Invalid vat_data value type')


class VatData(BaseObject):
    """
    Данные об НДС, если товар или услуга облагается налогом (в параметре `type` передано значение ~`calculated`).
    """  # noqa: E501

    __type = None
    """Код способа расчета НДС."""  # noqa: E501

    __rate = None
    """Налоговая ставка (в процентах). Возможные значения: `7`, `10`, `18` и `20`. """  # noqa: E501

    __amount = None
    """Сумма НДС."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели VatData.

        :return: type модели VatData.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели VatData.

        :param value: type модели VatData.
        :type value: str
        """
        if value in VatDataType.__dict__.values():
            self.__type = str(value)
        else:
            raise ValueError('Invalid type value')

    @property
    def rate(self):
        """
        Возвращает rate модели VatData.

        :return: rate модели VatData.
        :rtype: str
        """
        return self.__rate

    @rate.setter
    def rate(self, value):
        """
        Устанавливает rate модели VatData.

        :param value: rate модели VatData.
        :type value: str
        """
        if value in VatDataRate.__dict__.values():
            self.__rate = int(value)
        else:
            raise ValueError('Invalid rate value')

    @property
    def amount(self):
        """
        Возвращает amount модели VatData.

        :return: amount модели VatData.
        :rtype: object
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели VatData.

        :param value: amount модели VatData.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')


class VatDataType:
    """
    Тип способа расчета НДС.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    CALCULATED = 'calculated'
    """Сумма НДС включена в сумму платежа."""
    MIXED = 'mixed'
    """Разные ставки НДС для разных товаров."""
    UNTAXED = 'untaxed'
    """Сумма платежа НДС не облагается."""


class VatDataRate:
    """
    Налоговая ставка НДС.
    """   # noqa: E501

    """
    Список допустимых значений
    """
    RATE_7 = 7
    """7%."""
    RATE_10 = 10
    """10%."""
    RATE_18 = 18
    """18%."""
    RATE_20 = 20
    """20%."""



# -*- coding: utf-8 -*-
from yookassa.domain.request import DealRequest


class DealRequestBuilder(object):
    """
    Конструктор запроса на подтверждение оплаты.
    """  # noqa: E501

    def __init__(self):
        self.__request = DealRequest()

    def set_type(self, value):
        """
        Устанавливает type модели DealRequest.

        :param value: type модели DealRequest.
        :type value: str
        :rtype: DealRequestBuilder
        """
        self.__request.type = value
        return self

    def set_fee_moment(self, value):
        """
        Устанавливает fee_moment модели DealRequest.

        :param value: fee_moment модели DealRequest.
        :type value: str
        :rtype: DealRequestBuilder
        """
        self.__request.fee_moment = value
        return self

    def set_description(self, value):
        """
        Устанавливает description модели DealRequest.

        :param value: description модели DealRequest.
        :type value: str
        :rtype: DealRequestBuilder
        """
        self.__request.description = value
        return self

    def set_metadata(self, value):
        """
        Устанавливает metadata модели DealRequest.

        :param value: metadata модели DealRequest.
        :type value: dict[str, str]
        :rtype: DealRequestBuilder
        """
        self.__request.metadata = value
        return self

    def build(self):
        """
        Возвращает request модели DealRequestBuilder.

        :return: request модели DealRequestBuilder.
        :rtype: DealRequest
        """
        return self.__request



# -*- coding: utf-8 -*-
from yookassa.domain.common.response_object import ResponseObject


class WebhookResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе информации о вебхуке.
    """  # noqa: E501

    __id = None
    """Идентификатор webhook."""  # noqa: E501

    __url = None
    """URL, на который ЮKassa отправляет уведомления."""  # noqa: E501

    __event = None
    """Событие, о котором уведомляет ЮKassa."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели WebhookResponse.

        :return: id модели WebhookResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели WebhookResponse.

        :param value: id модели WebhookResponse.
        :type value: str
        """
        self.__id = value

    @property
    def event(self):
        """
        Возвращает event модели WebhookResponse.

        :return: event модели WebhookResponse.
        :rtype: str
        """
        return self.__event

    @event.setter
    def event(self, value):
        """
        Устанавливает event модели WebhookResponse.

        :param value: event модели WebhookResponse.
        :type value: str
        """
        self.__event = value

    @property
    def url(self):
        """
        Возвращает url модели WebhookResponse.

        :return: url модели WebhookResponse.
        :rtype: str
        """
        return self.__url

    @url.setter
    def url(self, value):
        """
        Устанавливает url модели WebhookResponse.

        :param value: url модели WebhookResponse.
        :type value: str
        """
        self.__url = value


class WebhookList(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе списка вебхуков.
    """  # noqa: E501

    __type = None
    """Формат выдачи результатов запроса. Возможное значение: `list` (список). """  # noqa: E501

    __items = None
    """Массив вебхуков."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели WebhookList.

        :return: type модели WebhookList.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели WebhookList.

        :param value: type модели WebhookList.
        :type value: str
        """
        self.__type = value

    @property
    def items(self):
        """
        Возвращает items модели WebhookList.

        :return: items модели WebhookList.
        :rtype: list[WebhookResponse]
        """
        return self.__items

    @items.setter
    def items(self, value):
        """
        Устанавливает items модели WebhookList.

        :param value: items модели WebhookList.
        :type value: list[WebhookResponse]
        """
        if isinstance(value, list):
            self.__items = [WebhookResponse(webhook) for webhook in value]
        else:
            self.__items = value






# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class Receiver(BaseObject):
    """Реквизиты получателя оплаты при %[пополнении электронного кошелька, банковского счета или баланса телефона](/developers/payment-acceptance/scenario-extensions/receiver-data)."""  # noqa: E501

    __type = None
    """Код получателя оплаты."""

    @property
    def type(self):
        """Возвращает type модели ReceiverBankAccount.

        :return: type модели ReceiverBankAccount.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """Устанавливает type модели ReceiverBankAccount.

        :param value: type модели ReceiverBankAccount.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = value


class ReceiverBankAccount(Receiver):
    """Реквизиты для пополнения банковского счета."""  # noqa: E501

    __account_number = None
    """Номер банковского счета. Формат — 20 символов."""  # noqa: E501

    __bic = None
    """Банковский идентификационный код (БИК) банка, в котором открыт счет. Формат — 9 символов."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(ReceiverBankAccount, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not ReceiverType.BANK_ACCOUNT:
            self.type = ReceiverType.BANK_ACCOUNT

    @property
    def account_number(self):
        """Возвращает account_number модели ReceiverBankAccount.

        :return: account_number модели ReceiverBankAccount.
        :rtype: str
        """
        return self.__account_number

    @account_number.setter
    def account_number(self, value):
        """Устанавливает account_number модели ReceiverBankAccount.

        :param value: account_number модели ReceiverBankAccount.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `account_number`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 20:
            raise ValueError("Invalid value for `account_number`, length must be less than or equal to `20`")  # noqa: E501
        if value is not None and not re.search(r'^[\\d]{20}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `account_number`, must be a follow pattern or equal to `/[\\d]{20}/`")  # noqa: E501
        self.__account_number = value

    @property
    def bic(self):
        """Возвращает bic модели ReceiverBankAccount.

        :return: bic модели ReceiverBankAccount.
        :rtype: str
        """
        return self.__bic

    @bic.setter
    def bic(self, value):
        """Устанавливает bic модели ReceiverBankAccount.

        :param value: bic модели ReceiverBankAccount.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `bic`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 9:
            raise ValueError("Invalid value for `bic`, length must be less than or equal to `9`")  # noqa: E501
        if value is not None and not re.search(r'^[\\d]{9}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `bic`, must be a follow pattern or equal to `/[\\d]{9}/`")  # noqa: E501
        self.__bic = value


class ReceiverDigitalWallet(BaseObject):
    """Реквизиты для пополнения баланса электронного кошелька."""  # noqa: E501

    __type = None
    """Код получателя оплаты."""  # noqa: E501

    __account_number = None
    """Идентификатор электронного кошелька для пополнения. Максимум 20 символов."""  # noqa: E501

    @property
    def type(self):
        """Возвращает type модели ReceiverDigitalWallet.

        :return: type модели ReceiverDigitalWallet.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """Устанавливает type модели ReceiverDigitalWallet.

        :param value: type модели ReceiverDigitalWallet.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = value

    @property
    def account_number(self):
        """Возвращает account_number модели ReceiverDigitalWallet.

        :return: account_number модели ReceiverDigitalWallet.
        :rtype: str
        """
        return self.__account_number

    @account_number.setter
    def account_number(self, value):
        """Устанавливает account_number модели ReceiverDigitalWallet.

        :param value: account_number модели ReceiverDigitalWallet.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `account_number`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 20:
            raise ValueError("Invalid value for `account_number`, length must be less than or equal to `20`")  # noqa: E501
        self.__account_number = value


class ReceiverMobileBalance(BaseObject):
    """Реквизиты для пополнения баланса телефона."""  # noqa: E501

    __type = None
    """Код получателя оплаты."""  # noqa: E501

    __phone = None

    @property
    def type(self):
        """Возвращает type модели ReceiverMobileBalance.

        :return: type модели ReceiverMobileBalance.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """Устанавливает type модели ReceiverMobileBalance.

        :param value: type модели ReceiverMobileBalance.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = value

    @property
    def phone(self):
        """Возвращает phone модели ReceiverMobileBalance.

        :return: phone модели ReceiverMobileBalance.
        :rtype: str
        """
        return self.__phone

    @phone.setter
    def phone(self, value):
        """Устанавливает phone модели ReceiverMobileBalance.

        :param value: phone модели ReceiverMobileBalance.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `phone`, must not be `None`")  # noqa: E501
        self.__phone = value


class ReceiverType:
    """Код получателя оплаты."""  # noqa: E501

    """
    Список допустимых значений
    """
    BANK_ACCOUNT = "bank_account"
    DIGITAL_WALLET = "digital_wallet"
    MOBILE_BALANCE = "mobile_balance"




# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class MerchantCustomerBankAccount(BaseObject):
    """
    Данные банковского счета, открытого в вашей системе. Необходимо передавать, если пользователь %[пополняет свой счет](/developers/payment-acceptance/scenario-extensions/bank-account-in-merchant-system).
    """  # noqa: E501

    __account_number = None
    """Номер банковского счета. Формат — 20 символов."""  # noqa: E501

    __bic = None
    """Банковский идентификационный код (БИК) банка, в котором открыт счет."""  # noqa: E501

    @property
    def account_number(self):
        """
        Возвращает account_number модели MerchantCustomerBankAccount.

        :return: account_number модели MerchantCustomerBankAccount.
        :rtype: str
        """
        return self.__account_number

    @account_number.setter
    def account_number(self, value):
        """
        Устанавливает account_number модели MerchantCustomerBankAccount.

        :param value: account_number модели MerchantCustomerBankAccount.
        :type value: str
        """
        if value is not None and not re.search(r'^[0-9]{20}$', value):  # noqa: E501
            raise ValueError("Invalid value for `account_number`, must be a follow pattern or equal to `/[0-9]{20}/`")  # noqa: E501
        self.__account_number = value

    @property
    def bic(self):
        """
        Возвращает bic модели MerchantCustomerBankAccount.

        :return: bic модели MerchantCustomerBankAccount.
        :rtype: str
        """
        return self.__bic

    @bic.setter
    def bic(self, value):
        """
        Устанавливает bic модели MerchantCustomerBankAccount.

        :param value: bic модели MerchantCustomerBankAccount.
        :type value: str
        """
        if value is not None and not re.search(r'^\d{9}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `bic`, must be a follow pattern or equal to `/\d{9}/`")  # noqa: E501
        self.__bic = value



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class PaymentData(BaseObject):
    """
    Базовый класс генерируемых объектов Payment.
    """  # noqa: E501

    __type = None
    """Тип метода оплаты."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели PaymentData.

        :return: type модели PaymentData.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели PaymentData.

        :param value: type модели PaymentData.
        :type value: str
        """
        self.__type = str(value)


class ResponsePaymentData(PaymentData):
    """
    Класс, описывающий основные свойства и методы платежных методов.
    """  # noqa: E501

    __id = None
    """Идентификатор способа оплаты."""  # noqa: E501

    __saved = None
    """С помощью сохраненного способа оплаты можно проводить %[безакцептные списания](/developers/payment-acceptance/scenario-extensions/recurring-payments)."""  # noqa: E501

    __title = None
    """Название способа оплаты."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели ResponsePaymentData.

        :return: id модели ResponsePaymentData.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели ResponsePaymentData.

        :param value: id модели ResponsePaymentData.
        :type value: str
        """
        self.__id = str(value)

    @property
    def saved(self):
        """
        Возвращает saved модели ResponsePaymentData.

        :return: saved модели ResponsePaymentData.
        :rtype: bool
        """
        return self.__saved

    @saved.setter
    def saved(self, value):
        """
        Устанавливает saved модели ResponsePaymentData.

        :param value: saved модели ResponsePaymentData.
        :type value: bool
        """
        self.__saved = bool(value)

    @property
    def title(self):
        """
        Возвращает title модели ResponsePaymentData.

        :return: title модели ResponsePaymentData.
        :rtype: str
        """
        return self.__title

    @title.setter
    def title(self, value):
        """
        Устанавливает title модели ResponsePaymentData.

        :param value: title модели ResponsePaymentData.
        :type value: str
        """
        self.__title = str(value)




# -*- coding: utf-8 -*-
from yookassa.domain.common import ResponseObject
from yookassa.domain.models import Settlement
from yookassa.domain.models.receipt_data.industry_details import IndustryDetails
from yookassa.domain.models.receipt_data.operational_details import OperationalDetails
from yookassa.domain.response import ReceiptItemResponse


class ReceiptResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе информации о чеке.
    """  # noqa: E501

    __id = None
    """Идентификатор чека в ЮKassa."""  # noqa: E501

    __type = None
    """Тип чека в онлайн-кассе: приход (payment) или возврат прихода (refund)."""  # noqa: E501

    __refund_id = None
    """Идентификатор возврата, для которого был сформирован чек. Отсутствует в чеке платежа."""  # noqa: E501

    __payment_id = None
    """Идентификатор платежа, для которого был сформирован чек."""  # noqa: E501

    __status = None
    """Статус доставки данных для чека в онлайн-кассу. """  # noqa: E501

    __fiscal_document_number = None
    """Номер фискального документа."""  # noqa: E501

    __fiscal_storage_number = None
    """Номер фискального накопителя в кассовом аппарате."""  # noqa: E501

    __fiscal_attribute = None
    """Фискальный признак чека. Формируется фискальным накопителем на основе данных, переданных для регистрации чека."""  # noqa: E501

    __registered_at = None
    """Дата и время формирования чека в фискальном накопителе. Указывается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)."""  # noqa: E501

    __fiscal_provider_id = None
    """Идентификатор чека в онлайн-кассе. Присутствует, если чек удалось зарегистрировать."""  # noqa: E501

    __items = []
    """Список товаров в чеке (не более 100 товаров)."""  # noqa: E501

    __settlements = []
    """Перечень совершенных расчетов."""  # noqa: E501

    __on_behalf_of = None
    """Идентификатор магазина, от имени которого нужно отправить чек. Выдается ЮKassa."""  # noqa: E501

    __tax_system_code = None
    """Система налогообложения магазина (тег в 54 ФЗ — 1055)."""  # noqa: E501

    __receipt_industry_details = []
    """Отраслевой реквизит предмета расчета (тег в 54 ФЗ — 1260)."""  # noqa: E501

    __receipt_operational_details = None
    """Операционный реквизит чека (тег в 54 ФЗ — 1270)."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели ReceiptResponse.

        :return: id модели ReceiptResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели ReceiptResponse.

        :param value: id модели ReceiptResponse.
        :type value: str
        """
        self.__id = str(value)

    @property
    def type(self):
        """
        Возвращает type модели ReceiptResponse.

        :return: type модели ReceiptResponse.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели ReceiptResponse.

        :param value: type модели ReceiptResponse.
        :type value: str
        """
        self.__type = str(value)

    @property
    def payment_id(self):
        """
        Возвращает payment_id модели ReceiptResponse.

        :return: payment_id модели ReceiptResponse.
        :rtype: str
        """
        return self.__payment_id

    @payment_id.setter
    def payment_id(self, value):
        """
        Устанавливает payment_id модели ReceiptResponse.

        :param value: payment_id модели ReceiptResponse.
        :type value: str
        """
        self.__payment_id = str(value)

    @property
    def refund_id(self):
        """
        Возвращает refund_id модели ReceiptResponse.

        :return: refund_id модели ReceiptResponse.
        :rtype: str
        """
        return self.__refund_id

    @refund_id.setter
    def refund_id(self, value):
        """
        Устанавливает refund_id модели ReceiptResponse.

        :param value: refund_id модели ReceiptResponse.
        :type value: str
        """
        self.__refund_id = str(value)

    @property
    def status(self):
        """
        Возвращает status модели ReceiptResponse.

        :return: status модели ReceiptResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели ReceiptResponse.

        :param value: status модели ReceiptResponse.
        :type value: str
        """
        self.__status = str(value)

    @property
    def receipt_registration(self):
        """
        Возвращает status модели ReceiptResponse.

        :return: status модели ReceiptResponse.
        :rtype: str
        """
        return self.status

    @receipt_registration.setter
    def receipt_registration(self, value):
        """
        Устанавливает status модели ReceiptResponse.

        :param value: status модели ReceiptResponse.
        :type value: str
        """
        self.status = value

    @property
    def fiscal_document_number(self):
        """
        Возвращает fiscal_document_number модели ReceiptResponse.

        :return: fiscal_document_number модели ReceiptResponse.
        :rtype: str
        """
        return self.__fiscal_document_number

    @fiscal_document_number.setter
    def fiscal_document_number(self, value):
        """
        Устанавливает fiscal_document_number модели ReceiptResponse.

        :param value: fiscal_document_number модели ReceiptResponse.
        :type value: str
        """
        self.__fiscal_document_number = str(value)

    @property
    def fiscal_storage_number(self):
        """
        Возвращает fiscal_storage_number модели ReceiptResponse.

        :return: fiscal_storage_number модели ReceiptResponse.
        :rtype: str
        """
        return self.__fiscal_storage_number

    @fiscal_storage_number.setter
    def fiscal_storage_number(self, value):
        """
        Устанавливает fiscal_storage_number модели ReceiptResponse.

        :param value: fiscal_storage_number модели ReceiptResponse.
        :type value: str
        """
        self.__fiscal_storage_number = str(value)

    @property
    def fiscal_attribute(self):
        """
        Возвращает fiscal_attribute модели ReceiptResponse.

        :return: fiscal_attribute модели ReceiptResponse.
        :rtype: str
        """
        return self.__fiscal_attribute

    @fiscal_attribute.setter
    def fiscal_attribute(self, value):
        """
        Устанавливает fiscal_attribute модели ReceiptResponse.

        :param value: fiscal_attribute модели ReceiptResponse.
        :type value: str
        """
        self.__fiscal_attribute = str(value)

    @property
    def registered_at(self):
        """
        Возвращает registered_at модели ReceiptResponse.

        :return: registered_at модели ReceiptResponse.
        :rtype: datetime
        """
        return self.__registered_at

    @registered_at.setter
    def registered_at(self, value):
        """
        Устанавливает registered_at модели ReceiptResponse.

        :param value: registered_at модели ReceiptResponse.
        :type value: datetime
        """
        self.__registered_at = value

    @property
    def fiscal_provider_id(self):
        """
        Возвращает fiscal_provider_id модели ReceiptResponse.

        :return: fiscal_provider_id модели ReceiptResponse.
        :rtype: str
        """
        return self.__fiscal_provider_id

    @fiscal_provider_id.setter
    def fiscal_provider_id(self, value):
        """
        Устанавливает fiscal_provider_id модели ReceiptResponse.

        :param value: fiscal_provider_id модели ReceiptResponse.
        :type value: str
        """
        self.__fiscal_provider_id = str(value)

    @property
    def items(self):
        """
        Возвращает items модели ReceiptResponse.

        :return: items модели ReceiptResponse.
        :rtype: list[ReceiptItemResponse]
        """
        return self.__items

    @items.setter
    def items(self, value):
        """
        Устанавливает items модели ReceiptResponse.

        :param value: items модели ReceiptResponse.
        :type value: list[ReceiptItemResponse]
        """
        if isinstance(value, list):
            self.__items = [ReceiptItemResponse(item) for item in value]
        else:
            self.__items = []

    @property
    def settlements(self):
        """
        Возвращает settlements модели ReceiptResponse.

        :return: settlements модели ReceiptResponse.
        :rtype: list[Settlement]
        """
        return self.__settlements

    @settlements.setter
    def settlements(self, value):
        """
        Устанавливает settlements модели ReceiptResponse.

        :param value: settlements модели ReceiptResponse.
        :type value: list[Settlement]
        """
        if isinstance(value, list):
            self.__settlements = [Settlement(item) for item in value]
        else:
            self.__settlements = []

    @property
    def on_behalf_of(self):
        """
        Возвращает on_behalf_of модели ReceiptResponse.

        :return: on_behalf_of модели ReceiptResponse.
        :rtype: str
        """
        return self.__on_behalf_of

    @on_behalf_of.setter
    def on_behalf_of(self, value):
        """
        Устанавливает on_behalf_of модели ReceiptResponse.

        :param value: on_behalf_of модели ReceiptResponse.
        :type value: str
        """
        self.__on_behalf_of = str(value)

    @property
    def tax_system_code(self):
        """
        Возвращает tax_system_code модели ReceiptResponse.

        :return: tax_system_code модели ReceiptResponse.
        :rtype: int
        """
        return self.__tax_system_code

    @tax_system_code.setter
    def tax_system_code(self, value):
        """
        Устанавливает tax_system_code модели ReceiptResponse.

        :param value: tax_system_code модели ReceiptResponse.
        :type value: int
        """
        self.__tax_system_code = int(value)

    @property
    def receipt_industry_details(self):
        """
        Возвращает receipt_industry_details модели ReceiptResponse.

        :return: receipt_industry_details модели ReceiptResponse.
        :rtype: list[IndustryDetails]
        """
        return self.__receipt_industry_details

    @receipt_industry_details.setter
    def receipt_industry_details(self, value):
        """
        Устанавливает receipt_industry_details модели ReceiptResponse.

        :param value: receipt_industry_details модели ReceiptResponse.
        :type value: list[IndustryDetails]
        """
        if isinstance(value, list):
            self.__receipt_industry_details = [IndustryDetails(item) for item in value]
        else:
            self.__receipt_industry_details = []

    @property
    def receipt_operational_details(self):
        """
        Возвращает receipt_operational_details модели ReceiptResponse.

        :return: receipt_operational_details модели ReceiptResponse.
        :rtype: OperationalDetails
        """
        return self.__receipt_operational_details

    @receipt_operational_details.setter
    def receipt_operational_details(self, value):
        """
        Устанавливает receipt_operational_details модели ReceiptResponse.

        :param value: receipt_operational_details модели ReceiptResponse.
        :type value: OperationalDetails
        """
        if isinstance(value, dict):
            self.__receipt_operational_details = OperationalDetails(value)
        else:
            self.__receipt_operational_details = value



# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class BadRequestError(ApiError):
    """
    Неправильный запрос. Чаще всего этот статус выдается из-за нарушения правил взаимодействия с API.
    """  # noqa: E501
    HTTP_CODE = 400



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models.payment_data.electronic_certificate.electronic_certificate import ElectronicCertificate


class ElectronicCertificateApprovedPaymentArticle(BaseObject):
    """Товарная позиция в одобренной корзине покупки при оплате по электронному сертификату."""  # noqa: E501

    __article_number = None
    """Порядковый номер товара в корзине. От 1 до 999 включительно. """  # noqa: E501

    __tru_code = None
    """Код ТРУ. 30 символов, две группы цифр, разделенные точкой. Формат: ~`NNNNNNNNN.NNNNNNNNNYYYYMMMMZZZ`, где ~`NNNNNNNNN.NNNNNNNNN` — код вида ТРУ по [Перечню ТРУ](https://esnsi.gosuslugi.ru/classifiers/10616/data?pg=1&p=1), ~`YYYY` — код производителя, ~`MMMM` — код модели, ~`ZZZ` — код страны производителя. Пример: ~`329921120.06001010200080001643`  [Как сформировать код ТРУ](/developers/payment-acceptance/integration-scenarios/manual-integration/other/electronic-certificate/basics#payments-preparations-tru-code) """  # noqa: E501

    __article_code = None
    """Код товара в вашей системе. Максимум 128 символов. """  # noqa: E501

    __certificates = None
    """Список электронных сертификатов, которые используются для оплаты покупки."""  # noqa: E501

    @property
    def article_number(self):
        """Возвращает article_number модели ElectronicCertificateApprovedPaymentArticle.

        :return: article_number модели ElectronicCertificateApprovedPaymentArticle.
        :rtype: int
        """
        return self.__article_number

    @article_number.setter
    def article_number(self, value):
        """Устанавливает article_number модели ElectronicCertificateApprovedPaymentArticle.

        :param value: article_number модели ElectronicCertificateApprovedPaymentArticle.
        :type value: int
        """
        self.__article_number = value

    @property
    def tru_code(self):
        """Возвращает tru_code модели ElectronicCertificateApprovedPaymentArticle.

        :return: tru_code модели ElectronicCertificateApprovedPaymentArticle.
        :rtype: str
        """
        return self.__tru_code

    @tru_code.setter
    def tru_code(self, value):
        """Устанавливает tru_code модели ElectronicCertificateApprovedPaymentArticle.

        :param value: tru_code модели ElectronicCertificateApprovedPaymentArticle.
        :type value: str
        """
        self.__tru_code = value

    @property
    def article_code(self):
        """Возвращает article_code модели ElectronicCertificateApprovedPaymentArticle.

        :return: article_code модели ElectronicCertificateApprovedPaymentArticle.
        :rtype: str
        """
        return self.__article_code

    @article_code.setter
    def article_code(self, value):
        """Устанавливает article_code модели ElectronicCertificateApprovedPaymentArticle.

        :param value: article_code модели ElectronicCertificateApprovedPaymentArticle.
        :type value: str
        """
        self.__article_code = value

    @property
    def certificates(self):
        """Возвращает certificates модели ElectronicCertificateApprovedPaymentArticle.

        :return: certificates модели ElectronicCertificateApprovedPaymentArticle.
        :rtype: list[ElectronicCertificate]
        """
        return self.__certificates

    @certificates.setter
    def certificates(self, value):
        """Устанавливает certificates модели ElectronicCertificateApprovedPaymentArticle.

        :param value: certificates модели ElectronicCertificateApprovedPaymentArticle.
        :type value: list[ElectronicCertificate]
        """
        if isinstance(value, list):
            certificates_array = []
            for certificatesData in value:
                if isinstance(certificatesData, dict):
                    certificates_array.append(ElectronicCertificate(certificatesData))
                elif isinstance(certificatesData, ElectronicCertificate):
                    certificates_array.append(certificatesData)
                else:
                    raise TypeError('Invalid certificates data type in ElectronicCertificateApprovedPaymentArticle.certificates')

            self.__certificates = certificates_array
        else:
            raise TypeError('Invalid certificates value type in ElectronicCertificateApprovedPaymentArticle')





# -*- coding: utf-8 -*-

class Locale:
    """
     Класс, представляющий модель Locale.

     Язык интерфейса, писем и смс, которые будет видеть или получать пользователь. Формат соответствует [ISO/IEC 15897](https://en.wikipedia.org/wiki/Locale_(computer_software)).

     Возможные значения:
     - `ru_RU` - Русский
     - `en_US` - English

     Регистр важен.
    """  # noqa: E501

    RUSSIAN = 'ru_RU'
    """Русский"""
    ENGLISH = 'en_US'
    """English"""



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount

DESCRIPTION_MAX_LENGTH = 128


class Transfer(BaseObject):
    """
    Данные о распределении денег — сколько и в какой магазин нужно перевести. Необходимо передавать, если вы используете %[Сплитование платежей](/developers/solutions-for-platforms/split-payments/basics).
    """  # noqa: E501

    __account_id = None
    """Идентификатор магазина, в пользу которого вы принимаете оплату."""  # noqa: E501

    __amount = None
    """Сумма, которую необходимо перечислить магазину."""  # noqa: E501

    __platform_fee_amount = None
    """Комиссия за проданные товары и услуги, которая удерживается с магазина в вашу пользу."""  # noqa: E501

    __description = None
    """Описание транзакции, которое продавец увидит в личном кабинете ЮKassa. (например: «Заказ маркетплейса №72»)."""  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы с платежами (например, ваш внутренний идентификатор заказа)."""  # noqa: E501

    @property
    def account_id(self):
        """
        Возвращает account_id модели Transfer.

        :return: account_id модели Transfer.
        :rtype: str
        """
        return self.__account_id

    @account_id.setter
    def account_id(self, value):
        """
        Устанавливает account_id модели Transfer.

        :param value: account_id модели Transfer.
        :type value: str
        """
        self.__account_id = str(value)

    @property
    def amount(self):
        """
        Возвращает amount модели Transfer.

        :return: amount модели Transfer.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели Transfer.

        :param value: amount модели Transfer.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid transfer.amount value type')

    @property
    def platform_fee_amount(self):
        """
        Возвращает platform_fee_amount модели Transfer.

        :return: platform_fee_amount модели Transfer.
        :rtype: Amount
        """
        return self.__platform_fee_amount

    @platform_fee_amount.setter
    def platform_fee_amount(self, value):
        """
        Устанавливает platform_fee_amount модели Transfer.

        :param value: platform_fee_amount модели Transfer.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__platform_fee_amount = Amount(value)
        elif isinstance(value, Amount):
            self.__platform_fee_amount = value
        else:
            raise TypeError('Invalid transfer.platform_fee_amount value type')

    @property
    def description(self):
        """
        Возвращает description модели Transfer.

        :return: description модели Transfer.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели Transfer.

        :param value: description модели Transfer.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            if len(cast_value) <= DESCRIPTION_MAX_LENGTH:
                self.__description = cast_value
            else:
                raise ValueError('The value of the description parameter is too long. Max length is {}'.format(DESCRIPTION_MAX_LENGTH))  # noqa: E501

    @property
    def metadata(self):
        """
        Возвращает metadata модели Transfer.

        :return: metadata модели Transfer.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели Transfer.

        :param value: metadata модели Transfer.
        :type value: dict[str, str]
        """
        if type(value) is dict:
            self.__metadata = value



# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class ForbiddenError(ApiError):
    """
    Секретный ключ или OAuth-токен верный, но не хватает прав для совершения операции.
    """  # noqa: E501
    HTTP_CODE = 403




from yookassa.domain.models.amount import Amount
from yookassa.domain.models.cancellation_details import CancellationDetails, CancellationDetailsPartyCode, \
    CancellationDetailsReasonCode, PayoutCancellationDetailsReasonCode, RefundCancellationDetailsReasonCode
from yookassa.domain.models.currency import Currency
from yookassa.domain.models.personal_data import PersonalDataType, PersonalDataStatus
from yookassa.domain.models.receipt import Receipt, ReceiptCustomer, ReceiptItem
from yookassa.domain.models.receipt_data.receipt_item_supplier import ReceiptItemSupplier
from yookassa.domain.models.payment_data.request.airline import Airline, Passenger, Leg
from yookassa.domain.models.payment_data.response.authorization_details import AuthorizationDetails
from yookassa.domain.models.payment_data.recipient import Recipient
from yookassa.domain.models.refund_data.refund_source import RefundSource
from yookassa.domain.models.sbp_participant_bank import SbpParticipantBank
from yookassa.domain.models.self_employed import PayoutSelfEmployed, SelfEmployedStatus
from yookassa.domain.models.settlement import Settlement, SettlementType, SettlementPayoutType
from yookassa.domain.models.transfer import Transfer
from yookassa.domain.models.deal import DealStatus, DealType, FeeMoment, PaymentDealInfo, PayoutDealInfo, \
    RefundDealInfo, RefundDealData
from yookassa.domain.models.me import Me
from yookassa.domain.models.settings import FiscalizationData, FiscalizationProvider



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class FiscalizationData(BaseObject):
    """
    Настройки магазина для %[отправки чеков в налоговую](/developers/payment-acceptance/receipts/basics).
    Присутствует, если вы запрашивали настройки магазина и этот магазин использует решения ЮKassa для отправки чеков. Отсутствует, если магазин еще не включал отправку чеков через ЮKassa.
    """  # noqa: E501

    __enabled = None
    """В настройках магазина включена отправка чеков. Возможные значения:  * ~`true` — магазин отправляет данные для чеков через ЮKassa; * ~`false` — магазин выключил отправку чеков через ЮKassa. """  # noqa: E501

    __provider = None
    """Решение ЮKassa, которое магазин использует для отправки чеков."""  # noqa: E501

    @property
    def enabled(self):
        """
        Возвращает enabled модели FiscalizationData.

        :return: enabled модели FiscalizationData.
        :rtype: bool
        """
        return self.__enabled

    @enabled.setter
    def enabled(self, value):
        """
        Устанавливает enabled модели FiscalizationData.

        :param value: enabled модели FiscalizationData.
        :type value: bool
        """
        self.__enabled = value

    @property
    def provider(self):
        """
        Возвращает provider модели FiscalizationData.

        :return: provider модели FiscalizationData.
        :rtype: str
        """
        return self.__provider

    @provider.setter
    def provider(self, value):
        """
        Устанавливает provider модели FiscalizationData.

        :param value: provider модели FiscalizationData.
        :type value: str
        """
        self.__provider = value



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import PaymentMethodType
from yookassa.domain.models.payment_data.electronic_certificate.electronic_certificate_article import \
    ElectronicCertificateArticle
from yookassa.domain.models.payment_data.request.electronic_certificate_payment_data import \
    ElectronicCertificatePaymentData
from yookassa.domain.models.payment_data.request.payment_data_bank_card import PaymentDataBankCard


class PaymentDataElectronicCertificate(PaymentDataBankCard):
    """Данные для оплаты по электронному сертификату."""  # noqa: E501

    __electronic_certificate = None

    __articles = None
    """Корзина покупки (в терминах НСПК) — список товаров, которые можно оплатить по сертификату.  Необходимо передавать только при [оплате на готовой странице ЮKassa](/developers/payment-acceptance/integration-scenarios/manual-integration/other/electronic-certificate/ready-made-payment-form). """  # noqa: E501


    def __init__(self, *args, **kwargs):
        super(PaymentDataElectronicCertificate, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.ELECTRONIC_CERTIFICATE:
            self.type = PaymentMethodType.ELECTRONIC_CERTIFICATE

    @property
    def electronic_certificate(self):
        """Возвращает electronic_certificate модели PaymentMethodDataElectronicCertificate.

        :return: electronic_certificate модели PaymentMethodDataElectronicCertificate.
        :rtype: ElectronicCertificatePaymentData
        """
        return self.__electronic_certificate

    @electronic_certificate.setter
    def electronic_certificate(self, value):
        """Устанавливает electronic_certificate модели PaymentMethodDataElectronicCertificate.

        :param value: electronic_certificate модели PaymentMethodDataElectronicCertificate.
        :type value: ElectronicCertificatePaymentData
        """
        if isinstance(value, dict):
            self.__electronic_certificate = ElectronicCertificatePaymentData(value)
        elif isinstance(value, ElectronicCertificatePaymentData):
            self.__electronic_certificate = value
        else:
            raise TypeError('Invalid electronic_certificate data type in PaymentMethodDataElectronicCertificate.electronic_certificate')

    @property
    def articles(self):
        """Возвращает articles модели PaymentMethodDataElectronicCertificate.

        :return: articles модели PaymentMethodDataElectronicCertificate.
        :rtype: list[ElectronicCertificateArticle]
        """
        return self.__articles

    @articles.setter
    def articles(self, value):
        """Устанавливает articles модели PaymentMethodDataElectronicCertificate.

        :param value: articles модели PaymentMethodDataElectronicCertificate.
        :type value: list[ElectronicCertificateArticle]
        """
        if isinstance(value, list):
            articles_array = []
            for articlesData in value:
                if isinstance(articlesData, dict):
                    articles_array.append(ElectronicCertificateArticle(articlesData))
                elif isinstance(articlesData, ElectronicCertificateArticle):
                    articles_array.append(articlesData)
                else:
                    raise TypeError('Invalid articles data type in PaymentMethodDataElectronicCertificate.articles')

            self.__articles = articles_array
        else:
            raise TypeError('Invalid articles value type in PaymentMethodDataElectronicCertificate')





# -*- coding: utf-8 -*-
import re

from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models import Amount
from yookassa.domain.models.payment_data.payment_data import ResponsePaymentData


class PaymentDataSberLoan(ResponsePaymentData):
    """
    Оплата в кредит или рассрочку от СберБанка.
    """  # noqa: E501

    __loan_option = None
    """Тариф кредита, который пользователь выбрал при оплате. 
    Возможные значения:  
    `loan` — кредит; 
    `installments_XX` — рассрочка, где ~`XX` — количество месяцев для выплаты рассрочки. Например, ~`installments_3` — рассрочка на 3 месяца.  Присутствует для платежей в статусе ~`waiting_for_capture` и ~`succeeded`. """  # noqa: E501

    __discount_amount = None
    """Сумма скидки для рассрочки."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataSberLoan, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.SBER_LOAN:
            self.type = PaymentMethodType.SBER_LOAN

    @property
    def loan_option(self):
        """
        Возвращает loan_option модели PaymentDataSberLoan.

        :return: loan_option модели PaymentDataSberLoan.
        :rtype: str
        """
        return self.__loan_option

    @loan_option.setter
    def loan_option(self, value):
        """
        Устанавливает loan_option модели PaymentDataSberLoan.

        :param value: loan_option модели PaymentDataSberLoan.
        :type value: str
        """
        cast_value = str(value)
        if re.match('^loan|installments_([0-9]+)$', cast_value):
            self.__loan_option = cast_value
        else:
            raise ValueError('Invalid loan_option value type')

    @property
    def discount_amount(self):
        """
        Возвращает discount_amount модели PaymentDataSberLoan.

        :return: discount_amount модели PaymentDataSberLoan.
        :rtype: Amount
        """
        return self.__discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        """
        Устанавливает discount_amount модели PaymentDataSberLoan.

        :param value: discount_amount модели PaymentDataSberLoan.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__discount_amount = Amount(value)
        elif isinstance(value, Amount):
            self.__discount_amount = value
        else:
            raise TypeError('Invalid discount_amount value type')



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class RequestRefundData(BaseObject):
    """
    Базовый класс генерируемых объектов ResponseRefundData.
    """  # noqa: E501

    __type = None
    """Код способа оплаты."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели ResponseRefundData.

        :return: type модели ResponseRefundData.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели ResponseRefundData.

        :param value: type модели ResponseRefundData.
        :type value: str
        """
        self.__type = str(value)


class ResponseRefundData(BaseObject):
    """
    Базовый класс генерируемых объектов ResponseRefundData.
    """  # noqa: E501

    __type = None
    """Код способа оплаты."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели ResponseRefundData.

        :return: type модели ResponseRefundData.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели ResponseRefundData.

        :param value: type модели ResponseRefundData.
        :type value: str
        """
        self.__type = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class OperationalDetails(BaseObject):
    """
    Данные операционного реквизита чека
    """  # noqa: E501

    __operation_id = None
    """Идентификатор операции (тег в 54 ФЗ — 1271). Число от 0 до 255. """  # noqa: E501

    __value = None
    """Данные операции (тег в 54 ФЗ — 1272)."""  # noqa: E501

    __created_at = None
    """Время создания операции (тег в 54 ФЗ — 1273). Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    @property
    def operation_id(self):
        """
        Возвращает operation_id модели OperationalDetails.

        :return: operation_id модели OperationalDetails.
        :rtype: int
        """
        return self.__operation_id

    @operation_id.setter
    def operation_id(self, value):
        """
        Устанавливает operation_id модели OperationalDetails.

        :param value: operation_id модели OperationalDetails.
        :type value: int
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_id`, must not be `None`")  # noqa: E501
        if not isinstance(value, int):  # noqa: E501
            raise TypeError("Invalid value type for `operation_id`, must be `int`")  # noqa: E501
        if value is not None and value > 255:  # noqa: E501
            raise ValueError("Invalid value for `operation_id`, must be a value less than or equal to `255`")  # noqa: E501
        if value is not None and value < 0:  # noqa: E501
            raise ValueError("Invalid value for `operation_id`, must be a value greater than or equal to `0`")  # noqa: E501
        self.__operation_id = value

    @property
    def value(self):
        """
        Возвращает value модели OperationalDetails.

        :return: value модели OperationalDetails.
        :rtype: str
        """
        return self.__value

    @value.setter
    def value(self, value):
        """
        Устанавливает value модели OperationalDetails.

        :param value: value модели OperationalDetails.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 64:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `64`")  # noqa: E501
        self.__value = value

    @property
    def created_at(self):
        """
        Возвращает created_at модели OperationalDetails.

        :return: created_at модели OperationalDetails.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """
        Устанавливает created_at модели OperationalDetails.

        :param value: created_at модели OperationalDetails.
        :type value: datetime
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501
        self.__created_at = value



# -*- coding: utf-8 -*-
from datetime import datetime, timedelta

from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.confirmation.confirmation import Confirmation
from yookassa.domain.models.confirmation.confirmation_factory import ConfirmationFactory
from yookassa.domain.models.deal import PaymentDealInfo
from yookassa.domain.models.payment_data.payment_data import PaymentData
from yookassa.domain.models.payment_data.payment_data_factory import PaymentDataFactory
from yookassa.domain.models.payment_data.recipient import Recipient
from yookassa.domain.models.payment_data.request.airline import Airline
from yookassa.domain.models.payment_data.request.fraud_data import FraudData
from yookassa.domain.models.payment_data.request.payment_data_bank_card import PaymentDataBankCard
from yookassa.domain.models.payment_data.request.receiver import Receiver
from yookassa.domain.models.payment_data.request.receiver_factory import ReceiverFactory
from yookassa.domain.models.receipt import Receipt
from yookassa.domain.models.transfer import Transfer

DESCRIPTION_MAX_LENGTH = 128
MERCHANT_CUSTOMER_MAX_LENGTH = 200


class PaymentRequest(RequestObject):
    """
    Объект запроса к API на проведение нового платежа.
    """  # noqa: E501

    __amount = None
    """Сумма создаваемого платежа."""  # noqa: E501

    __description = None
    """Описание транзакции (не более 128 символов), которое вы увидите в личном кабинете ЮKassa, а пользователь — при оплате. Например: «Оплата заказа № 72 для user@yoomoney.ru». """  # noqa: E501

    __receipt = None
    """Данные фискального чека 54-ФЗ."""  # noqa: E501

    __recipient = None
    """Получатель платежа, если задан."""  # noqa: E501

    __payment_token = None
    """Одноразовый токен для проведения оплаты, сформированный с помощью %[Checkout.js](/developers/payment-acceptance/integration-scenarios/checkout-js/basics) или %[мобильного SDK](/developers/payment-acceptance/integration-scenarios/mobile-sdks/basics). """  # noqa: E501

    __payment_method_id = None
    """Идентификатор %[сохраненного способа оплаты](/developers/payment-acceptance/scenario-extensions/recurring-payments)."""  # noqa: E501

    __payment_method_data = None
    """Данные используемые для создания метода оплаты."""  # noqa: E501

    __confirmation = None
    """Способ подтверждения платежа."""  # noqa: E501

    __save_payment_method = None
    """Сохранение платежных данных (с их помощью можно проводить повторные %[безакцептные списания](/developers/payment-acceptance/scenario-extensions/recurring-payments)). Значение ~`true` инициирует создание многоразового `payment_method`."""  # noqa: E501

    __capture = None
    """<p>%[Автоматический прием](/developers/payment-acceptance/getting-started/payment-process#capture-true) поступившего платежа.</p> """  # noqa: E501

    __client_ip = None
    """IPv4 или IPv6-адрес пользователя. Если не указан, используется IP-адрес TCP-подключения."""  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    __airline = None
    """Объект с данными для продажи авиабилетов."""  # noqa: E501

    __transfers = []
    """Данные о распределении денег — сколько и в какой магазин нужно перевести. Необходимо передавать, если вы используете %[Сплитование платежей](/developers/solutions-for-platforms/split-payments/basics)."""  # noqa: E501

    __deal = None
    """Данные о сделке, в составе которой проходит платеж."""  # noqa: E501

    __fraud_data = None
    """Информация для проверки операции на мошенничество."""  # noqa: E501

    __merchant_customer_id = None
    """Идентификатор покупателя в вашей системе, например электронная почта или номер телефона."""  # noqa: E501

    __receiver = None
    """Реквизиты получателя оплаты при пополнении электронного кошелька, банковского счета или баланса телефона"""  # noqa: E501

    @property
    def amount(self):
        """
        Возвращает amount модели PaymentRequest.

        :return: amount модели PaymentRequest.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели PaymentRequest.

        :param value: amount модели PaymentRequest.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def description(self):
        """
        Возвращает description модели PaymentRequest.

        :return: description модели PaymentRequest.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели PaymentRequest.

        :param value: description модели PaymentRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            if len(cast_value) <= DESCRIPTION_MAX_LENGTH:
                self.__description = cast_value
            else:
                raise ValueError('The value of the description parameter is too long. Max length is {}'.format(DESCRIPTION_MAX_LENGTH))  # noqa: E501

    @property
    def receipt(self):
        """
        Возвращает receipt модели PaymentRequest.

        :return: receipt модели PaymentRequest.
        :rtype: Receipt
        """
        return self.__receipt

    @receipt.setter
    def receipt(self, value):
        """
        Устанавливает receipt модели PaymentRequest.

        :param value: receipt модели PaymentRequest.
        :type value: Receipt
        """
        if isinstance(value, dict):
            self.__receipt = Receipt(value)
        elif isinstance(value, Receipt):
            self.__receipt = value
        else:
            raise TypeError('Invalid receipt_request value type')

    @property
    def recipient(self):
        """
        Возвращает recipient модели PaymentRequest.

        :return: recipient модели PaymentRequest.
        :rtype: Recipient
        """
        return self.__recipient

    @recipient.setter
    def recipient(self, value):
        """
        Устанавливает recipient модели PaymentRequest.

        :param value: recipient модели PaymentRequest.
        :type value: Recipient
        """
        if isinstance(value, dict):
            self.__recipient = Recipient(value)
        elif isinstance(value, Recipient):
            self.__recipient = value
        else:
            raise TypeError('Invalid recipient value type')

    @property
    def payment_token(self):
        """
        Возвращает payment_token модели PaymentRequest.

        :return: payment_token модели PaymentRequest.
        :rtype: str
        """
        return self.__payment_token

    @payment_token.setter
    def payment_token(self, value):
        """
        Устанавливает payment_token модели PaymentRequest.

        :param value: payment_token модели PaymentRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__payment_token = cast_value
        else:
            raise TypeError('Invalid payment_token value')

    @property
    def payment_method_id(self):
        """
        Возвращает payment_method_id модели PaymentRequest.

        :return: payment_method_id модели PaymentRequest.
        :rtype: str
        """
        return self.__payment_method_id

    @payment_method_id.setter
    def payment_method_id(self, value):
        """
        Устанавливает payment_method_id модели PaymentRequest.

        :param value: payment_method_id модели PaymentRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__payment_method_id = cast_value

    @property
    def payment_method_data(self):
        """
        Возвращает payment_method_data модели PaymentRequest.

        :return: payment_method_data модели PaymentRequest.
        :rtype: PaymentData
        """
        return self.__payment_method_data

    @payment_method_data.setter
    def payment_method_data(self, value):
        """
        Устанавливает payment_method_data модели PaymentRequest.

        :param value: payment_method_data модели PaymentRequest.
        :type value: PaymentData
        """
        if isinstance(value, dict):
            self.__payment_method_data = PaymentDataFactory().create(value, self.context())
        elif isinstance(value, PaymentData):
            self.__payment_method_data = value
        else:
            raise TypeError('Invalid payment_method_data type')

    @property
    def confirmation(self):
        """
        Возвращает confirmation модели PaymentRequest.

        :return: confirmation модели PaymentRequest.
        :rtype: Confirmation
        """
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        """
        Устанавливает confirmation модели PaymentRequest.

        :param value: confirmation модели PaymentRequest.
        :type value: Confirmation
        """
        if isinstance(value, dict):
            self.__confirmation = ConfirmationFactory().create(value, self.context())
        elif isinstance(value, Confirmation):
            self.__confirmation = value
        else:
            raise TypeError('Invalid confirmation type')

    @property
    def save_payment_method(self):
        """
        Возвращает save_payment_method модели PaymentRequest.

        :return: save_payment_method модели PaymentRequest.
        :rtype: bool
        """
        return self.__save_payment_method

    @save_payment_method.setter
    def save_payment_method(self, value):
        """
        Устанавливает save_payment_method модели PaymentRequest.

        :param value: save_payment_method модели PaymentRequest.
        :type value: bool
        """
        self.__save_payment_method = bool(value)

    @property
    def capture(self):
        """
        Возвращает capture модели PaymentRequest.

        :return: capture модели PaymentRequest.
        :rtype: bool
        """
        return self.__capture

    @capture.setter
    def capture(self, value):
        """
        Устанавливает capture модели PaymentRequest.

        :param value: capture модели PaymentRequest.
        :type value: bool
        """
        self.__capture = bool(value)

    @property
    def client_ip(self):
        """
        Возвращает client_ip модели PaymentRequest.

        :return: client_ip модели PaymentRequest.
        :rtype: str
        """
        return self.__client_ip

    @client_ip.setter
    def client_ip(self, value):
        """
        Устанавливает client_ip модели PaymentRequest.

        :param value: client_ip модели PaymentRequest.
        :type value: str
        """
        self.__client_ip = str(value)

    @property
    def airline(self):
        """
        Возвращает airline модели PaymentRequest.

        :return: airline модели PaymentRequest.
        :rtype: Airline
        """
        return self.__airline

    @airline.setter
    def airline(self, value):
        """
        Устанавливает airline модели PaymentRequest.

        :param value: airline модели PaymentRequest.
        :type value: Airline
        """
        if isinstance(value, dict):
            self.__airline = Airline(value)
        elif isinstance(value, Airline):
            self.__airline = value
        else:
            raise TypeError('Invalid airline type')

    @property
    def metadata(self):
        """
        Возвращает metadata модели PaymentRequest.

        :return: metadata модели PaymentRequest.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели PaymentRequest.

        :param value: metadata модели PaymentRequest.
        :type value: dict[str, str]
        """
        if type(value) is dict:
            self.__metadata = value

    @property
    def transfers(self):
        """
        Возвращает transfers модели PaymentRequest.

        :return: transfers модели PaymentRequest.
        :rtype: list[Transfer]
        """
        return self.__transfers

    @transfers.setter
    def transfers(self, value):
        """
        Устанавливает transfers модели PaymentRequest.

        :param value: transfers модели PaymentRequest.
        :type value: list[Transfer]
        """
        if isinstance(value, list):
            self.__transfers = [Transfer(item) for item in value]
        elif value is None:
            self.__transfers = []
        else:
            raise TypeError('Invalid transfers data type in payment_request.transfers')

    @property
    def deal(self):
        """
        Возвращает deal модели PaymentRequest.

        :return: deal модели PaymentRequest.
        :rtype: PaymentDealInfo
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели PaymentRequest.

        :param value: deal модели PaymentRequest.
        :type value: PaymentDealInfo
        """
        if isinstance(value, dict):
            self.__deal = PaymentDealInfo(value)
        elif isinstance(value, PaymentDealInfo):
            self.__deal = value
        else:
            raise TypeError('Invalid deal type')

    @property
    def fraud_data(self):
        """
        Возвращает fraud_data модели PaymentRequest.
        Больше не поддерживается. Вместо него нужно использовать `receiver`

        :return: fraud_data модели PaymentRequest.
        :rtype: FraudData
        """
        return self.__fraud_data

    @fraud_data.setter
    def fraud_data(self, value):
        """
        Устанавливает fraud_data модели PaymentRequest.
        Больше не поддерживается. Вместо него нужно использовать `receiver`

        :param value: fraud_data модели PaymentRequest.
        :type value: FraudData
        """
        if isinstance(value, dict):
            self.__fraud_data = FraudData(value)
        elif isinstance(value, FraudData):
            self.__fraud_data = value
        else:
            raise TypeError('Invalid fraud_data type in payment_request.fraud_data')

    @property
    def merchant_customer_id(self):
        """
        Возвращает merchant_customer_id модели PaymentRequest.

        :return: merchant_customer_id модели PaymentRequest.
        :rtype: str
        """
        return self.__merchant_customer_id

    @merchant_customer_id.setter
    def merchant_customer_id(self, value):
        """
        Устанавливает merchant_customer_id модели PaymentRequest.

        :param value: merchant_customer_id модели PaymentRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            if len(cast_value) <= MERCHANT_CUSTOMER_MAX_LENGTH:
                self.__merchant_customer_id = cast_value
            else:
                raise ValueError('The value of the merchant_customer_id parameter is too long. Max length is {}'.format(MERCHANT_CUSTOMER_MAX_LENGTH))  # noqa: E501

    @property
    def receiver(self):
        """Возвращает receiver модели CreatePaymentRequest.

        :return: receiver модели CreatePaymentRequest.
        :rtype: CreatePaymentRequestReceiver
        """
        return self.__receiver

    @receiver.setter
    def receiver(self, value):
        """Устанавливает receiver модели CreatePaymentRequest.

        :param value: receiver модели CreatePaymentRequest.
        :type value: Receiver
        """
        if isinstance(value, dict):
            self.__receiver = ReceiverFactory().create(value, self.context())
        elif isinstance(value, Receiver):
            self.__receiver = value
        else:
            raise TypeError('Invalid receiver type')


    def validate(self):
        """
        Влидация данных модели PaymentRequest.
        """
        amount = self.amount
        if amount is None:
            self.__set_validation_error('Payment amount not specified')

        if amount.value <= 0.0:
            self.__set_validation_error('Invalid payment amount value: ' + str(amount.value))

        if self.receipt is not None and self.receipt.has_items:
            if self.receipt.customer is None:
                self.__set_validation_error('Customer is empty in receipt')

            email = self.receipt.customer.email
            phone = self.receipt.customer.phone
            if not email and not phone:
                self.__set_validation_error('Both email and phone values are empty in receipt')

            if self.receipt.tax_system_code is None:
                for item in self.receipt.items:
                    if item.vat_code is None:
                        self.__set_validation_error('Item vat_code and receipt tax_system_id not specified')

        if self.payment_token:
            if self.payment_method_id:
                self.__set_validation_error('Both payment_token and payment_method_id values are specified')

            if self.payment_method_data:
                self.__set_validation_error('Both payment_token and payment_data values are specified')

        elif self.payment_method_id:
            if self.payment_method_data:
                self.__set_validation_error('Both payment_method_id and payment_data values are specified')

        if self.payment_method_data and isinstance(self.payment_method_data, PaymentDataBankCard) \
                and self.payment_method_data.card is not None:
            # Get current date with an offset.
            # Why? Because expiration is relative to the transaction
            # processor's timezone, which we don't know. 1 day allowance will
            # prevent any sorts of false negatives, leaving a small
            # less-than-day window for the unlikely false positives.
            # Account for GMT-12 to GMT+14 difference
            # + DST: https://www.timeanddate.com/time/dst/
            date_now = datetime.now() - timedelta(hours=26 + 1)

            # Expiry date is "valid thru", meaning it is valid until the last
            # second of the last day of the month in the date.
            date_expiry = datetime(
                year=int(self.payment_method_data.card.expiry_year),
                month=int(self.payment_method_data.card.expiry_month),
                day=1
            )
            # A little trick to add a month
            date_expiry += timedelta(days=31)
            date_expiry -= timedelta(days=date_expiry.day - 1)

            if date_now >= date_expiry:
                self.__set_validation_error('Card expired')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели PaymentRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.common.receipt_type import ReceiptType
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.receipt_data.receipt_customer import ReceiptCustomer
from yookassa.domain.models.receipt_data.additional_user_props import AdditionalUserProps
from yookassa.domain.models.receipt_data.industry_details import IndustryDetails
from yookassa.domain.models.receipt_data.operational_details import OperationalDetails
from yookassa.domain.models.settlement import Settlement
from yookassa.domain.request.receipt_item_request import ReceiptItemRequest


class ReceiptRequest(RequestObject):
    """
    Объект запроса к API на создание чека.
    """  # noqa: E501

    __type = None
    """Тип чека в онлайн-кассе: приход "payment" или возврат "refund"."""  # noqa: E501

    __payment_id = None
    """Идентификатор платежа в ЮKassa для отображения информации о чеке в личном кабинете, на платеж не влияет. Обязательный параметр при создании чека прихода. """  # noqa: E501

    __refund_id = None
    """Идентификатор возврата в ЮKassa для отображения информации о чеке в личном кабинете. Обязательный параметр при создании чека возврата прихода."""  # noqa: E501

    __customer = None
    """Информация о пользователе."""  # noqa: E501

    __items = []
    """Список товаров в чеке (не более 100 товаров)."""  # noqa: E501

    __send = None
    """Формирование чека в онлайн-кассе сразу после создания объекта чека. Сейчас можно передать только значение ~`true`. """  # noqa: E501

    __tax_system_code = None
    """Система налогообложения магазина (тег в 54 ФЗ — 1055).  Для сторонних онлайн-касс: обязательный параметр, если вы используете онлайн-кассу Атол Онлайн, обновленную до ФФД 1.2, или у вас несколько систем налогообложения, в остальных случаях не передается. %[Перечень возможных значений](/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#tax-systems)  Для Чеков от ЮKassa: параметр передавать не нужно, ЮKassa его проигнорирует. """  # noqa: E501

    __additional_user_props = None
    """Дополнительный реквизит пользователя."""  # noqa: E501

    __receipt_industry_details = None
    """Отраслевой реквизит чека (тег в 54 ФЗ — 1261). Нужно передавать, если используете ФФД 1.2."""  # noqa: E501

    __receipt_operational_details = None
    """Операционный реквизит чека."""  # noqa: E501

    __settlements = []
    """Перечень совершенных расчетов."""  # noqa: E501

    __on_behalf_of = None
    """Идентификатор магазина в ЮKassa."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели ReceiptRequest.

        :return: type модели ReceiptRequest.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели ReceiptRequest.

        :param value: type модели ReceiptRequest.
        :type value: str
        """
        self.__type = str(value)

    @property
    def payment_id(self):
        """
        Возвращает payment_id модели ReceiptRequest.

        :return: payment_id модели ReceiptRequest.
        :rtype: str
        """
        return self.__payment_id

    @payment_id.setter
    def payment_id(self, value):
        """
        Устанавливает payment_id модели ReceiptRequest.

        :param value: payment_id модели ReceiptRequest.
        :type value: str
        """
        self.__refund_id = None
        self.__payment_id = str(value)

    @property
    def refund_id(self):
        """
        Возвращает refund_id модели ReceiptRequest.

        :return: refund_id модели ReceiptRequest.
        :rtype: str
        """
        return self.__refund_id

    @refund_id.setter
    def refund_id(self, value):
        """
        Устанавливает refund_id модели ReceiptRequest.

        :param value: refund_id модели ReceiptRequest.
        :type value: str
        """
        self.__payment_id = None
        self.__refund_id = str(value)

    @property
    def customer(self):
        """
        Возвращает customer модели ReceiptRequest.

        :return: customer модели ReceiptRequest.
        :rtype: ReceiptCustomer
        """
        return self.__customer

    @customer.setter
    def customer(self, value):
        """
        Устанавливает customer модели ReceiptRequest.

        :param value: customer модели ReceiptRequest.
        :type value: ReceiptCustomer
        """
        if isinstance(value, dict):
            self.__customer = ReceiptCustomer(value)
        elif isinstance(value, ReceiptCustomer):
            self.__customer = value
        else:
            raise TypeError('Invalid customer value type in ReceiptRequest')

    @property
    def email(self):
        """
        Возвращает email модели ReceiptRequest.

        :return: email модели ReceiptRequest.
        :rtype: str
        """
        return self.__customer.email if self.__customer is not None else None

    @email.setter
    def email(self, value):
        """
        Устанавливает email модели ReceiptRequest.

        :param value: email модели ReceiptRequest.
        :type value: str
        """
        if self.__customer is None:
            self.__customer = ReceiptCustomer()
        self.__customer.email = str(value)

    @property
    def phone(self):
        """
        Возвращает phone модели ReceiptRequest.

        :return: phone модели ReceiptRequest.
        :rtype: str
        """
        return self.__customer.phone if self.__customer is not None else None

    @phone.setter
    def phone(self, value):
        """
        Устанавливает phone модели ReceiptRequest.

        :param value: phone модели ReceiptRequest.
        :type value: str
        """
        if self.__customer is None:
            self.__customer = ReceiptCustomer()
        self.__customer.phone = str(value)

    @property
    def items(self):
        """
        Возвращает items модели ReceiptRequest.

        :return: items модели ReceiptRequest.
        :rtype: list[ReceiptItemRequest]
        """
        return self.__items

    @items.setter
    def items(self, value):
        """
        Устанавливает items модели ReceiptRequest.

        :param value: items модели ReceiptRequest.
        :type value: list[ReceiptItemRequest]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(ReceiptItemRequest(item))
                elif isinstance(item, ReceiptItemRequest):
                    items.append(item)
                else:
                    raise TypeError('Invalid item type in ReceiptRequest.items')
            self.__items = items
        elif value is None:
            self.__items = []
        else:
            raise TypeError('Invalid items value type in ReceiptRequest')

    @property
    def send(self):
        """
        Возвращает send модели ReceiptRequest.

        :return: send модели ReceiptRequest.
        :rtype: bool
        """
        return self.__send

    @send.setter
    def send(self, value):
        """
        Устанавливает send модели ReceiptRequest.

        :param value: send модели ReceiptRequest.
        :type value: bool
        """
        if isinstance(value, bool):
            self.__send = value
        else:
            raise TypeError('Invalid send value type in ReceiptRequest')

    @property
    def tax_system_code(self):
        """
        Возвращает tax_system_code модели ReceiptRequest.

        :return: tax_system_code модели ReceiptRequest.
        :rtype: int
        """
        return self.__tax_system_code

    @tax_system_code.setter
    def tax_system_code(self, value):
        """
        Устанавливает tax_system_code модели ReceiptRequest.

        :param value: tax_system_code модели ReceiptRequest.
        :type value: int
        """
        if isinstance(value, int):
            self.__tax_system_code = value
        else:
            raise TypeError('Invalid tax_system_code value type in ReceiptRequest')

    @property
    def additional_user_props(self):
        """
        Возвращает additional_user_props модели ReceiptRequest.

        :return: additional_user_props модели ReceiptRequest.
        :rtype: AdditionalUserProps
        """
        return self.__additional_user_props

    @additional_user_props.setter
    def additional_user_props(self, value):
        """
        Устанавливает additional_user_props модели ReceiptRequest.

        :param value: additional_user_props модели ReceiptRequest.
        :type value: AdditionalUserProps
        """
        if isinstance(value, dict):
            self.__additional_user_props = AdditionalUserProps(value)
        elif isinstance(value, AdditionalUserProps):
            self.__additional_user_props = value
        else:
            raise TypeError('Invalid additional_user_props data type in ReceiptRequest')

    @property
    def receipt_industry_details(self):
        """
        Возвращает receipt_industry_details модели ReceiptRequest.

        :return: receipt_industry_details модели ReceiptRequest.
        :rtype: list[IndustryDetails]
        """
        return self.__receipt_industry_details

    @receipt_industry_details.setter
    def receipt_industry_details(self, value):
        """
        Устанавливает receipt_industry_details модели ReceiptRequest.

        :param value: receipt_industry_details модели ReceiptRequest.
        :type value: list[IndustryDetails]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(IndustryDetails(item))
                elif isinstance(item, IndustryDetails):
                    items.append(item)
                else:
                    raise TypeError('Invalid receipt_industry_details data type in ReceiptRequest.receipt_industry_details')
            self.__receipt_industry_details = items
        else:
            raise TypeError('Invalid receipt_industry_details value type in ReceiptRequest')

    @property
    def receipt_operational_details(self):
        """
        Возвращает receipt_operational_details модели ReceiptRequest.

        :return: receipt_operational_details модели ReceiptRequest.
        :rtype: OperationalDetails
        """
        return self.__receipt_operational_details

    @receipt_operational_details.setter
    def receipt_operational_details(self, value):
        """
        Устанавливает receipt_operational_details модели ReceiptRequest.

        :param value: receipt_operational_details модели ReceiptRequest.
        :type value: OperationalDetails
        """
        if isinstance(value, dict):
            self.__receipt_operational_details = OperationalDetails(value)
        elif isinstance(value, OperationalDetails):
            self.__receipt_operational_details = value
        else:
            raise TypeError('Invalid receipt_operational_details data type in ReceiptRequest')

    @property
    def settlements(self):
        """
        Возвращает settlements модели ReceiptRequest.

        :return: settlements модели ReceiptRequest.
        :rtype: list[Settlement]
        """
        return self.__settlements

    @settlements.setter
    def settlements(self, value):
        """
        Устанавливает settlements модели ReceiptRequest.

        :param value: settlements модели ReceiptRequest.
        :type value: list[Settlement]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(Settlement(item))
                elif isinstance(item, Settlement):
                    items.append(item)
                else:
                    raise TypeError('Invalid settlement type in ReceiptRequest.settlements')
            self.__settlements = items
        elif value is None:
            self.__settlements = []
        else:
            raise TypeError('Invalid settlements value type in ReceiptRequest')

    @property
    def on_behalf_of(self):
        """
        Возвращает on_behalf_of модели ReceiptRequest.

        :return: on_behalf_of модели ReceiptRequest.
        :rtype: str
        """
        return self.__on_behalf_of

    @on_behalf_of.setter
    def on_behalf_of(self, value):
        """
        Устанавливает on_behalf_of модели ReceiptRequest.

        :param value: on_behalf_of модели ReceiptRequest.
        :type value: str
        """
        self.__on_behalf_of = str(value)

    def validate(self):
        """
        Влидация данных модели ReceiptRequest.
        """
        if self.type is None:
            self.__set_validation_error('ReceiptRequest.type not specified')

        if self.send is None:
            self.__set_validation_error('ReceiptRequest.send not specified')

        if self.customer is not None:
            email = self.customer.email
            phone = self.customer.phone
            if not email and not phone:
                self.__set_validation_error('Both email and phone values are empty in ReceiptRequest.customer')
        else:
            self.__set_validation_error('ReceiptRequest.customer not specified')

        if not self.has_items():
            self.__set_validation_error('ReceiptRequest.items not specified')

        if not self.has_settlements():
            self.__set_validation_error('ReceiptRequest.settlements not specified')

        if self.type is ReceiptType.PAYMENT and self.payment_id is None:
            self.__set_validation_error('ReceiptRequest.payment_id not specified')

        if self.type is ReceiptType.REFUND and self.refund_id is None and self.payment_id is None:
            self.__set_validation_error('ReceiptRequest.refund_id or ReceiptRequest.payment_id not specified')

    def has_items(self):
        """
        Проверяет, были ли установлены товары в чеке модели ReceiptRequest.

        :rtype: bool
        """
        return bool(self.items) and bool(len(self.items))

    def has_settlements(self):
        """
        Проверяет, был ли установлен перечень расчетов модели ReceiptRequest.

        :rtype: bool
        """
        return bool(self.settlements) and bool(len(self.settlements))

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели ReceiptRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.request.refund_request import RefundRequest


class RefundRequestBuilder(object):
    """
    Конструктор запроса на создание возврата средств.
    """  # noqa: E501

    def __init__(self):
        self.__request = RefundRequest()

    def set_payment_id(self, value):
        """
        Устанавливает payment_id модели RefundRequestBuilder.

        :param value: payment_id модели RefundRequestBuilder.
        :type value: str
        :rtype: RefundRequestBuilder
        """
        self.__request.payment_id = value
        return self

    def set_amount(self, value):
        """
        Устанавливает amount модели RefundRequestBuilder.

        :param value: amount модели RefundRequestBuilder.
        :type value: Amount
        :rtype: RefundRequestBuilder
        """
        self.__request.amount = value
        return self

    def set_description(self, value):
        """
        Устанавливает description модели RefundRequestBuilder.

        :param value: description модели RefundRequestBuilder.
        :type value: str
        :rtype: RefundRequestBuilder
        """
        self.__request.description = value
        return self

    def set_receipt(self, value):
        """
        Устанавливает receipt модели RefundRequestBuilder.

        :param value: receipt модели RefundRequestBuilder.
        :type value: Receipt
        :rtype: RefundRequestBuilder
        """
        self.__request.receipt = value
        return self

    def set_sources(self, value):
        """
        Устанавливает sources модели RefundRequestBuilder.

        :param value: sources модели RefundRequestBuilder.
        :type value: list[RefundSource]
        :rtype: RefundRequestBuilder
        """
        self.__request.sources = value
        return self

    def set_deal(self, value):
        """
        Устанавливает deal модели RefundRequestBuilder.

        :param value: deal модели RefundRequestBuilder.
        :type value: RefundDealData
        :rtype: RefundRequestBuilder
        """
        self.__request.deal = value
        return self

    def refund_method_data(self, value):
        """Устанавливает refund_method_data модели RefundRequest.

        :param value: refund_method_data модели RefundRequest.
        :type value: RequestRefundData
        :rtype: RefundRequestBuilder
        """
        self.__request.refund_method_data = value
        return self

    def build(self):
        """
        Возвращает request модели RefundRequestBuilder.

        :return: request модели RefundRequestBuilder.
        :rtype: RefundRequest
        """
        return self.__request



# -*- coding: utf-8 -*-


class CardType:
    """
    Тип банковской карты. 
    """  # noqa: E501

    """
    Список допустимых значений
    """
    MASTER_CARD = 'MasterCard'
    """MasterCard` (для карт Mastercard и Maestro)."""
    VISA = 'Visa'
    """Visa` (для карт Visa и Visa Electron)."""
    MIR = 'MIR'
    """Mir."""
    UNION_PAY = 'UnionPay'
    """UnionPay."""
    CUP = 'CUP'
    """CUP."""
    JCB = 'JCB'
    """JCB."""
    AMERICAN_EXPRESS = 'AmericanExpress'
    """AmericanExpress."""
    DINERS_CLUB = 'DinersClub'
    """DinersClub."""
    UNKNOWN = 'Unknown'
    """Unknown."""


class CardSource:
    """
    Источник данных банковской карты.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    APPLE_PAY = 'apple_pay'
    """Источник данных ApplePay."""
    GOOGLE_PAY = 'GooglePay'
    """Источник данных ApplePay."""
    MIR_PAY = 'mir_pay'
    """Источник данных MirPay."""



# -*- coding: utf-8 -*-


class HttpVerb(object):
    """
    Константы, представляющие глаголы http-метода. Возможные значения:

    * yookassa.domain.common.HttpVerb.GET
    * yookassa.domain.common.HttpVerb.POST
    * yookassa.domain.common.HttpVerb.PUT
    * yookassa.domain.common.HttpVerb.PATCH
    * yookassa.domain.common.HttpVerb.HEAD
    * yookassa.domain.common.HttpVerb.OPTIONS
    * yookassa.domain.common.HttpVerb.DELETE
    """  # noqa: E501

    """
    Список допустимых значений
    """
    GET = 'get'
    """Используется для получения данных от сервера"""
    POST = 'post'
    """Используется для отправки данных на сервер"""
    PUT = 'put'
    """Используется для обновление ресурса"""
    PATCH = 'patch'
    """Используется для частичного обновления ресурса"""
    HEAD = 'head'
    """Используется для получения только заголовков"""
    OPTIONS = 'options'
    """Используется для запроса информации об опциях соединения, доступных в цепочке запросов и ответов"""
    DELETE = 'delete'
    """Используется для удаление ресурса"""
